==> eclipse-orion-3.0-macosx.cocoa.x86.zip: eclipse/plugins/org.eclipse.orion.client.ui_2.0.0.v20130625-1702/web/orion/navigate/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/

//NLS_CHARSET=UTF-8
 
define({
	"Click one of the tasks below to create an Orion folder.  You can upload, import, or generate files.": "Click one of the tasks below to create an Orion folder.  You can upload, import, or generate files.",
	"Toggle Left Pane": "Toggle Left Pane",
	"Open or close the left pane": "Open or close the left pane",
	"Navigator": "Navigator",
	"Strings Xtrnalizr": "Strings Xtrnalizr",
	"Externalize Strings from JavaScript files in this folder": "Externalize Strings from JavaScript files in this folder",
	"Choose a Folder": "Choose a Folder",
	"Copy of ${0}": "Copy of ${0}",
	"Enter a new name for '${0}'": "Enter a new name for '${0}'",
	"Choose folder...": "Choose folder...",
	"Rename": "Rename",
	"Rename the selected files or folders": "Rename the selected files or folders",
	"Compare with each other": "Compare with each other",
	"Compare the selected 2 files with each other": "Compare the selected 2 files with each other",
	"Compare with...": "Compare with...",
	"Compare the selected folder with a specified folder": "Compare the selected folder with a specified folder",
	"Delete": "Delete",
	"Unknown item": "Unknown item",
	"Make Favorite": "Make Favorite",
	"Delete the selected files or folders": "Delete the selected files or folders",
	"Are you sure you want to delete these ${0} items?": "Are you sure you want to delete these ${0} items?",
	"Are you sure you want to delete '${0}'?": "Are you sure you want to delete '${0}'?",
	"Are you sure you want to delete '${0}' from the favorites?": "Are you sure you want to delete '${0}' from the favorites?",
	"Are you sure you want to delete these ${0} favorites?": "Are you sure you want to delete these ${0} favorites?",
	"You can create favorites by selecting any file or folder in the navigator and choosing ${0} from the ${1} menu.": "You can create favorites by selecting any file or folder in the navigator and choosing ${0} from the ${1} menu.",
	"Export as zip": "Export as zip",
	"Create a zip file of the folder contents and download it": "Create a zip file of the folder contents and download it",
	"New File": "New File",
	"Create a new file": "Create a new file",
	"Name:" : "Name:",
	"New Folder": "New Folder",
	"Folder name:": "Folder name:",
	"Create a new folder": "Create a new folder",
	"Creating folder": "Creating folder",
	"Folder": "Folder",
	"Create an empty folder": "Create an empty folder",
	"Create an empty folder on the Orion server.  You can import, upload, or create content in the editor.": "Create an empty folder on the Orion server.  You can import, upload, or create content in the editor.",
	"Sample HTML5 Site": "Sample HTML5 Site",
	"Generate a sample": "Generate a sample",
	"Generate an HTML5 \"Hello World\" website, including JavaScript, HTML, and CSS files.": "Generate an HTML5 \"Hello World\" website, including JavaScript, HTML, and CSS files.",
	"Creating a folder for ${0}": "Creating a folder for ${0}",
	"SFTP Import": "SFTP Import",
	"Import content from SFTP": "Import content from SFTP",
	"Import content from an SFTP location into an Orion folder.  You will be prompted for the SFTP location and credentials.": "Import content from an SFTP location into an Orion folder.  You will be prompted for the SFTP location and credentials.",
	"Imported Content": "Imported Content",
	"Upload a Zip": "Upload a Zip",
	"Upload content from a local zip file": "Upload content from a local zip file",
	"Upload content from a local zip file into an Orion folder.  You will be prompted for the local zip file.": "Upload content from a local zip file into an Orion folder.  You will be prompted for the local zip file.",
	"Uploaded Content": "Uploaded Content",
	"Creating an upload folder for ": "Creating an upload folder for ",
	"Clone Git Repository": "Clone Git Repository",
	"Clone a git repository": "Clone a git repository",
	"Go to the Orion repositories page to provide a git repository URL.  Once the repository is created, it will appear in the Navigator.": "Go to the Orion repositories page to provide a git repository URL.  Once the repository is created, it will appear in the Navigator.",
	"Link to Server": "Link to Server",
	"Link to existing content on the server": "Link to existing content on the server",
	"Create a folder that links to an existing folder on the server.": "Create a folder that links to an existing folder on the server.",
	"Server path:": "Server path:",
	"The name and server location were not specified.": "The name and server location were not specified.",
	"Go Up": "Go Up",
	"Move up to the parent folder": "Move up to the parent folder",
	"Import local file...": "Import local file...",
	"Copy files and folders from your local file system": "Copy files and folders from your local file system",
	"SFTP from...": "SFTP from...",
	"Copy files and folders from a specified SFTP connection": "Copy files and folders from a specified SFTP connection",
	"Importing from ${0}": "Importing from ${0}",
	"SFTP to...": "SFTP to...",
	"Copy files and folders to a specified SFTP location": "Copy files and folders to a specified SFTP location",
	"Exporting": "Exporting to ${0}",
	"Pasting ${0}": "Pasting ${0}",
	"Copy to": "Copy to",
	"Move to": "Move to",
	"Copying ${0}": "Copying ${0}",
	"Moving ${0}": "Moving ${0}",
	"Renaming ${0}": "Renaming ${0}",
	"Deleting ${0}": "Deleting ${0}",
	"Creating ${0}": "Creating ${0}",
	"Linking to ${0}": "Linking to ${0}",
	"Move files and folders to a new location": "Move files and folders to a new location",
	"Copy Items": "Copy Items",
	"Copy the selected items to the copy/paste buffer": "Copy the selected items to the copy/paste buffer",
	"Paste Items": "Paste Items",
	"Paste items from the copy/paste buffer": "Paste items from the copy/paste buffer",
	"Cannot paste into the Workspace root": "Cannot paste into the Workspace root",
	"Open With": "Open With",
	"Loading ": "Loading ",
	"New": "New",
	"Actions": "Actions",
	"Orion Content": "Orion Content",
	" is not supported in this file system": " is not supported in this file system",
	"Create new content" : "Create new content",
	"Favorites" : "Favorites",
	"Import from HTTP..." : "Import from HTTP...",
	"File URL:" : "File URL:",
	"Copy a file from a URL and optionally unzip it" : "Copy a file from a URL and optionally unzip it",
	"Unzip *.zip files:" : "Unzip *.zip files:",
	"Extracted from:" : "Extracted from:",
	"Did not drop ${0}.  Folder drop is not supported in this browser.": "Did not drop ${0}.  Folder drop is not supported in this browser.",
	"You cannot copy files directly into the workspace.  Create a folder first.": "You cannot copy files directly into the workspace.  Create a folder first.",
	"Unzip ${0}?": "Unzip ${0}?",
	"NoFile": "Use the ${0} to create new files and folders. Click a file to start coding." //$NON-NLS-1$ //$NON-NLS-0$
});

==> eclipse-orion-4.0-macosx.cocoa.x86.zip: eclipse/plugins/org.eclipse.orion.client.ui_2.0.0.v20131030-1824/web/orion/navigate/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/

//NLS_CHARSET=UTF-8
 
define({
	"Click one of the tasks below to create an Orion folder.  You can upload, import, or generate files.": "Click one of the tasks below to create an Orion folder.  You can upload, import, or generate files.",
	"Toggle Left Pane": "Toggle Left Pane",
	"Open or close the left pane": "Open or close the left pane",
	"Navigator": "Navigator",
	"Strings Xtrnalizr": "Strings Xtrnalizr",
	"Externalize Strings from JavaScript files in this folder": "Externalize Strings from JavaScript files in this folder",
	"Choose a Folder": "Choose a Folder",
	"Copy of ${0}": "Copy of ${0}",
	"Enter a new name for '${0}'": "Enter a new name for '${0}'",
	"Choose folder...": "Choose folder...",
	"Rename": "Rename",
	"Rename the selected files or folders": "Rename the selected files or folders",
	"Compare with each other": "Compare with each other",
	"Compare the selected 2 files with each other": "Compare the selected 2 files with each other",
	"Compare with...": "Compare with...",
	"Compare the selected folder with a specified folder": "Compare the selected folder with a specified folder",
	"Delete": "Delete",
	"Unknown item": "Unknown item",
	"Delete the selected files or folders": "Delete the selected files or folders",
	"Are you sure you want to delete these ${0} items?": "Are you sure you want to delete these ${0} items?",
	"Are you sure you want to delete '${0}'?": "Are you sure you want to delete '${0}'?",
	"Export as zip": "Export as zip",
	"Create a zip file of the folder contents and download it": "Create a zip file of the folder contents and download it",
	"New File": "New File",
	"Create a new file": "Create a new file",
	"Name:" : "Name:",
	"New Folder": "New Folder",
	"Folder name:": "Folder name:",
	"Create a new folder": "Create a new folder",
	"Creating folder": "Creating folder",
	"Folder": "Folder",
	"Create an empty folder": "Create an empty folder",
	"Create an empty folder on the Orion server.  You can import, upload, or create content in the editor.": "Create an empty folder on the Orion server.  You can import, upload, or create content in the editor.",
	"Sample HTML5 Site": "Sample HTML5 Site",
	"Generate a sample": "Generate a sample",
	"Generate an HTML5 \"Hello World\" website, including JavaScript, HTML, and CSS files.": "Generate an HTML5 \"Hello World\" website, including JavaScript, HTML, and CSS files.",
	"Creating a folder for ${0}": "Creating a folder for ${0}",
	"SFTP Import": "SFTP Import",
	"Import content from SFTP": "Import content from SFTP",
	"Import content from an SFTP location into an Orion folder.  You will be prompted for the SFTP location and credentials.": "Import content from an SFTP location into an Orion folder.  You will be prompted for the SFTP location and credentials.",
	"Imported Content": "Imported Content",
	"Upload a Zip": "Upload a Zip",
	"Upload content from a local zip file": "Upload content from a local zip file",
	"Upload content from a local zip file into an Orion folder.  You will be prompted for the local zip file.": "Upload content from a local zip file into an Orion folder.  You will be prompted for the local zip file.",
	"Uploaded Content": "Uploaded Content",
	"Creating an upload folder for ": "Creating an upload folder for ",
	"Clone Git Repository": "Clone Git Repository",
	"Clone a git repository": "Clone a git repository",
	"Go to the Orion repositories page to provide a git repository URL.  Once the repository is created, it will appear in the Navigator.": "Go to the Orion repositories page to provide a git repository URL.  Once the repository is created, it will appear in the Navigator.",
	"Link to Server": "Link to Server",
	"Link to existing content on the server": "Link to existing content on the server",
	"Create a folder that links to an existing folder on the server.": "Create a folder that links to an existing folder on the server.",
	"Server path:": "Server path:",
	"The name and server location were not specified.": "The name and server location were not specified.",
	"Go Up": "Go Up",
	"Move up to the parent folder": "Move up to the parent folder",
	"Go Into": "Go Into",
	"Move into the selected folder": "Move into the selected folder",
	"Import local file...": "Import local file...",
	"Copy files and folders from your local file system": "Copy files and folders from your local file system",
	"SFTP from...": "SFTP from...",
	"Copy files and folders from a specified SFTP connection": "Copy files and folders from a specified SFTP connection",
	"Importing from ${0}": "Importing from ${0}",
	"SFTP to...": "SFTP to...",
	"Copy files and folders to a specified SFTP location": "Copy files and folders to a specified SFTP location",
	"Exporting": "Exporting to ${0}",
	"Pasting ${0}": "Pasting ${0}",
	"Copy to": "Copy to",
	"Move to": "Move to",
	"Copying ${0}": "Copying ${0}",
	"Moving ${0}": "Moving ${0}",
	"Renaming ${0}": "Renaming ${0}",
	"Deleting ${0}": "Deleting ${0}",
	"Creating ${0}": "Creating ${0}",
	"Linking to ${0}": "Linking to ${0}",
	"Move files and folders to a new location": "Move files and folders to a new location",
	"Copy Items": "Copy Items",
	"Copy the selected items to the copy/paste buffer": "Copy the selected items to the copy/paste buffer",
	"Paste Items": "Paste Items",
	"Paste items from the copy/paste buffer": "Paste items from the copy/paste buffer",
	"Cannot paste into the Workspace root": "Cannot paste into the Workspace root",
	"Open With": "Open With",
	"Loading ": "Loading ",
	"New": "New",
	"Actions": "Actions",
	"Orion Content": "Orion Content",
	" is not supported in this file system": " is not supported in this file system",
	"Create new content" : "Create new content",
	"Import from HTTP..." : "Import from HTTP...",
	"File URL:" : "File URL:",
	"Copy a file from a URL and optionally unzip it" : "Copy a file from a URL and optionally unzip it",
	"Unzip *.zip files:" : "Unzip *.zip files:",
	"Extracted from:" : "Extracted from:",
	"Did not drop ${0}.  Folder drop is not supported in this browser.": "Did not drop ${0}.  Folder drop is not supported in this browser.",
	"You cannot copy files directly into the workspace.  Create a folder first.": "You cannot copy files directly into the workspace.  Create a folder first.",
	"Unzip ${0}?": "Unzip ${0}?",
	"NoFile": "Use the ${0} to create new files and folders. Click a file to start coding." //$NON-NLS-1$ //$NON-NLS-0$
});
